@@ -43,7 +43,6 @@
 Names here will cause complaints if bound.")
 
 (defvar org-node-changes--warned-about-titlegen nil)
-(defvar org-node-changes--warned-about-roam-id nil)
 (defvar org-node-changes--warned-about-fakeroam-v2 nil)
 (defun org-node-changes--onetime-warn-and-copy ()
   "Maybe print one-shot warnings.
@@ -75,22 +74,6 @@ value."
       (setq org-node-changes--warned-about-fakeroam-v2 t)
       (display-warning
        'org-node "Package org-node-fakeroam still v2, upgrade or remove")))
-  (unless org-node-changes--warned-about-roam-id
-    (when (and (fboundp 'org-link-get-parameter)
-               (not (or (and (bound-and-true-p org-roam-autosync-mode)
-                             (bound-and-true-p org-roam-db-update-on-save))
-                        (and (bound-and-true-p org-mem-roamy-db-mode)
-                             (bound-and-true-p org-mem-roamy-do-overwrite-real-db))))
-               (eq (org-link-get-parameter "id" :follow) 'org-roam-id-open))
-      (setq org-node-changes--warned-about-roam-id t)
-      (message
-       "%s" "Note: org-roam overrides ID-link behavior to prefer its own DB!
-As that DB is not being updated, links can send you to the wrong place.
-If `org-mem-do-sync-with-org-id' is t, you can safely revert to
-default ID-link behavior.  Add to initfiles:
-(with-eval-after-load 'org-roam-id
- (org-link-set-parameters
-  \"id\" :follow #'org-id-open :store #'org-id-store-link-maybe))")))
   (unless org-node-changes--warned-about-titlegen
     (when (help-function-arglist org-node-blank-input-title-generator)
       (setq org-node-changes--warned-about-titlegen t)
@@ -199,70 +182,48 @@ NAME, ARGLIST and BODY as in `defun'."
         (< org-mem--bump-int 13))
     (display-warning 'org-node "Update org-mem to use this version of org-node"))
 
-(define-obsolete-function-alias 'org-node-get-aliases                #'org-mem-roam-aliases                 "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-deadline               #'org-mem-deadline                     "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-file                   #'org-mem-file                         "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-file-title             #'org-mem-file-title-strict            "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-file-title-or-basename #'org-mem-file-title-or-basename       "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-id                     #'org-mem-id                           "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-id-links-to            #'org-mem-id-links-to-entry            "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-is-subtree             #'org-mem-subtree-p                    "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-level                  #'org-mem-entry-level                  "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-links-from             #'org-mem-links-from-id                "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-lnum                   #'org-mem-lnum                         "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-nodes-in-files         #'org-mem-entries-in                   "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-olp                    #'org-mem-olpath                       "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-olp-full               #'org-mem-olpath-with-file-title       "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-olp-with-self          #'org-mem-olpath-with-self             "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-olp-with-self-full     #'org-mem-olpath-with-self-with-file-title "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-pos                    #'org-mem-pos                          "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-priority               #'org-mem-priority                     "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-properties             #'org-mem-properties                   "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-props                  #'org-mem-properties                   "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-reflinks-to            #'org-mem-roam-reflinks-to-entry       "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-refs                   #'org-mem-roam-refs                    "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-scheduled              #'org-mem-scheduled                    "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-tags                   #'org-mem-tags                         "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-tags-inherited         #'org-mem-tags-inherited               "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-tags-local             #'org-mem-tags-local                   "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-tags-with-inheritance  #'org-mem-tags                         "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-title                  #'org-mem-entry-title                  "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-get-todo                   #'org-mem-todo-state                   "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-is-subtree                 #'org-mem-subtree-p                    "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-subtree-p                  #'org-mem-entry-subtree-p              "3.0.0 (May 2025)")
-(define-obsolete-function-alias 'org-node-insert-link-into-drawer    'org-node-insert-into-related          "3.3.3 (May 2025)")
+(org-node-changes--def-whiny-alias 'org-node-get-aliases                #'org-mem-roam-aliases                      "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-deadline               #'org-mem-deadline                          "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-file                   #'org-mem-file                              "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-file-title             #'org-mem-file-title-strict                 "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-file-title-or-basename #'org-mem-file-title-or-basename            "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-id                     #'org-mem-id                                "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-id-links-to            #'org-mem-id-links-to-entry                 "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-is-subtree             #'org-mem-subtree-p                         "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-level                  #'org-mem-entry-level                       "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-links-from             #'org-mem-links-from-id                     "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-lnum                   #'org-mem-lnum                              "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-nodes-in-files         #'org-mem-entries-in                        "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-olp                    #'org-mem-olpath                            "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-olp-full               #'org-mem-olpath-with-file-title            "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-olp-with-self          #'org-mem-olpath-with-self                  "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-olp-with-self-full     #'org-mem-olpath-with-self-with-file-title  "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-pos                    #'org-mem-pos                               "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-priority               #'org-mem-priority                          "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-properties             #'org-mem-properties                        "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-props                  #'org-mem-properties                        "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-reflinks-to            #'org-mem-roam-reflinks-to-entry            "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-refs                   #'org-mem-roam-refs                         "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-scheduled              #'org-mem-scheduled                         "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-tags                   #'org-mem-tags                              "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-tags-inherited         #'org-mem-tags-inherited                    "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-tags-local             #'org-mem-tags-local                        "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-tags-with-inheritance  #'org-mem-tags                              "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-title                  #'org-mem-entry-title                       "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-get-todo                   #'org-mem-todo-state                        "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-is-subtree                 #'org-mem-subtree-p                         "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-subtree-p                  #'org-mem-entry-subtree-p                   "3.0.0 (May 2025)" "February 2026")
+(org-node-changes--def-whiny-alias 'org-node-insert-link-into-drawer    'org-node-insert-into-related               "3.3.3 (May 2025)" "February 2026")
 (define-obsolete-function-alias 'org-node--goto                      'org-node-goto                         "3.8.0 (July 2025)")
 (define-obsolete-function-alias 'org-node--goto-id                   'org-node-goto-id                      "3.8.0 (July 2025)")
 (define-obsolete-function-alias 'org-node--infer-title-etc           'org-node-capture-infer-title-etc      "3.8.0 (July 2025)")
 (define-obsolete-function-alias 'org-node--pop-to-fresh-file-buffer  'org-node-pop-to-fresh-file-buffer     "3.8.0 (July 2025)")
-(define-obsolete-function-alias 'org-node-collection-main 'org-node-collection "2025-09-30")
-(define-obsolete-function-alias 'org-node-collection-basic 'org-node-collection "2025-09-30")
-
-(org-node-changes--def-whiny-alias 'org-node--dir-files-recursively         #'org-mem--dir-files-recursive              "3.0.0 (May 2025)" "August")
-(org-node-changes--def-whiny-alias 'org-node-abbrev-file-names              #'org-mem--fast-abbrev                      "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-by-id                          #'org-mem-entry-by-id                       "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-link-dest                      #'org-mem-link-target                       "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-link-origin                    #'org-mem-link-nearby-id                    "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-link-p                         #'org-mem-link-p                            "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-link-pos                       #'org-mem-link-pos                          "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-link-type                      #'org-mem-link-type                         "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-list-collisions                'org-mem-list-title-collisions              "3.0.0 (May 2025)" "September" t)
-(org-node-changes--def-whiny-alias 'org-node-list-dead-links                'org-mem-list-dead-id-links                 "3.0.0 (May 2025)" "September" t)
-(org-node-changes--def-whiny-alias 'org-node-list-scan-problems             'org-mem-list-problems                      "3.0.0 (May 2025)" "September" t)
-(org-node-changes--def-whiny-alias 'org-nodes-in-file                       #'org-mem-id-nodes-in-files                 "3.0.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node--general-org-work-buffer       #'org-mem-org-mode-scratch                  "3.1.1 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-forget-dir                     #'org-mem-forget-id-locations-recursively   "3.2.0 (May 2025)" "September" t)
-(org-node-changes--def-whiny-alias 'org-node-prefix-with-olp                'org-node-prepend-olp                       "3.3.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-prefix-with-tags               'org-node-prepend-tags                      "3.3.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-prefix-with-tags-and-olp       'org-node-prepend-tags-and-olp              "3.3.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-affix-with-olp-and-tags        'org-node-prepend-olp-append-tags           "3.3.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-affix-with-olp-and-tags-legacy 'org-node-prepend-olp-append-tags           "3.3.0 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node--end-of-meta-data              'org-node-full-end-of-meta-data             "3.3.10 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-list-file-coding-systems       'org-node-list-files                        "3.3.10 (May 2025)" "September")
-(org-node-changes--def-whiny-alias 'org-node-mk-auto-title                  'org-node-titlegen-untitled                 "3.3.12 (May 2025)" "August")
-(org-node-changes--def-whiny-alias 'org-node-title-to-filename              'org-node-title-to-filename-quiet           "3.4.3 (June 2025)" "October")
-(org-node-changes--def-whiny-alias 'org-node-peek                           'org-node-list-example                      "3.5.0 (June 2025)" "October" t)
-(org-node-changes--def-whiny-alias 'org-node-put-created                    'org-node-ensure-crtime-property            "3.7.0 (June 2025)" "October" t)
+(define-obsolete-function-alias 'org-node-collection-main            'org-node-collection                   "3.9.0 (October 2025)")
+(define-obsolete-function-alias 'org-node-collection-basic           'org-node-collection                   "3.9.0 (October 2025)")
+(define-obsolete-function-alias 'org-node-update-mtime               'org-node-update-mtime-property        "3.11.0 (December 2025)")
+(define-obsolete-function-alias 'org-node-sort-by-crtime             'org-node-sort-by-crtime-property      "3.11.1 (December 2025)")
+(define-obsolete-function-alias 'org-node-sort-by-crtime-cheap       'org-node-sort-by-crtime-property      "3.11.1 (December 2025)")
+(define-obsolete-function-alias 'org-node-sort-by-mtime-cheap        'org-node-sort-by-mtime-property       "3.11.1 (December 2025)")
 
 (provide 'org-node-changes)
 
